OC.L10N.register(
    "settings",
    {
    "Private" : "Privat",
    "Only visible to people matched via phone number integration through Talk on mobile" : "Kun synlig for personer som matches via telefonnummerintegrasjon via Talk på mobil",
    "Local" : "Lokal",
    "Only visible to people on this instance and guests" : "Kun synlig for personer i denne installasjonen og for gjester",
    "Federated" : "Sammenknyttet",
    "Only synchronize to trusted servers" : "Synkroniser kun til betrodde servere",
    "Published" : "Publisert",
    "Synchronize to trusted servers and the global and public address book" : "Synkroniser til betrodde servere og den globale og offentlige adresseboken",
    "Verify" : "Bekreft",
    "Verifying …" : "Bekrefter…",
    "Unable to change password" : "Kunne ikke endre passord",
    "Very weak password" : "Veldig svakt passord",
    "Weak password" : "Svakt passord",
    "So-so password" : "Bob-bob-passord",
    "Good password" : "Bra passord",
    "Strong password" : "Sterkt passord",
    "Groups" : "Grupper",
    "Group list is empty" : "Gruppeliste er tom",
    "Unable to retrieve the group list" : "Kunne ikke hente gruppelisten",
    "{actor} added you to group {group}" : "{actor} la deg til i gruppen {group}",
    "You added {user} to group {group}" : "Du la til {user} i gruppen {group}",
    "{actor} added {user} to group {group}" : "{actor} la {user} til i gruppen {group}",
    "An administrator added you to group {group}" : "En administrator la deg til i gruppen {group}",
    "An administrator added {user} to group {group}" : "En administrator la {user} til i gruppen {group}",
    "{actor} removed you from group {group}" : "{actor} fjernet deg fra gruppen {group}",
    "You removed {user} from group {group}" : "Du fjernet {user} fra gruppen {group}",
    "{actor} removed {user} from group {group}" : "{actor} fjernet {user} fra gruppen {group}",
    "An administrator removed you from group {group}" : "En administrator fjernet deg fra gruppen {group}",
    "An administrator removed {user} from group {group}" : "En administrator fjernet {user} fra gruppen {group}",
    "Your <strong>group memberships</strong> were modified" : "Dine <strong>gruppemedlemskap</strong> ble endret",
    "{actor} changed your password" : "{actor} endret ditt passord",
    "You changed your password" : "Du endret ditt passord",
    "Your password was reset by an administrator" : "Ditt passord ble tilbakestilt av en administrator",
    "Your password was reset" : "Passordet ditt ble nullstilt",
    "{actor} changed your email address" : "{actor} endret din e-postadresse",
    "You changed your email address" : "Du endret din e-postadresse",
    "Your email address was changed by an administrator" : "Din e-postadresse ble endret av en administrator",
    "You created an app password for a session named \"{token}\"" : "Du opprettet et app-passord for en økt kalt \"{token}\"",
    "An administrator created an app password for a session named \"{token}\"" : "En administrator opprettet et apppassord for en økt kalt \"{token}\"",
    "You deleted app password \"{token}\"" : "Du slettet app-passord \"{token}\"",
    "You renamed app password \"{token}\" to \"{newToken}\"" : "Du endret navn på app-passord \"{token}\" til \"{newToken}\"",
    "You granted filesystem access to app password \"{token}\"" : "Du har gitt filsystemtilgang til app-passord \"{token}\"",
    "You revoked filesystem access from app password \"{token}\"" : "Du tilbakekalte filsystemtilgang fra app-passordet \"{token}\"",
    "Security" : "Sikkerhet",
    "You successfully logged in using two-factor authentication (%1$s)" : "Din innlogging med to-trinns bekreftelse var velykket (%1$s)",
    "A login attempt using two-factor authentication failed (%1$s)" : "En innlogging med to-trinns bekreftelse mislyktes (%1$s)",
    "Remote wipe was started on %1$s" : "Fjernsletting ble startet på %1$s",
    "Remote wipe has finished on %1$s" : "Fjernsletting er ferdig på %1$s",
    "Your <strong>password</strong> or <strong>email</strong> was modified" : "Ditt <strong>passord</strong> eller din <strong>e-postadresse</strong> ble endret",
    "Settings" : "Innstillinger",
    "Could not remove app." : "Kunne ikke fjerne appen.",
    "Could not update app." : "Kunne ikke oppdatere appen.",
    "Wrong password" : "Feil passord",
    "Unable to change personal password" : "Kan ikke endre personlig passord",
    "Saved" : "Lagret",
    "No Login supplied" : "Ingen pålogging følger med",
    "Unable to change password. Password too long." : "Kan ikke endre passord. Passordet er for langt.",
    "Authentication error" : "Autentiseringsfeil",
    "Please provide an admin recovery password; otherwise, all account data will be lost." : "Vennligst oppgi et administratorgjenopprettingspassord; ellers vil alle kontodata gå tapt.",
    "Wrong admin recovery password. Please check the password and try again." : "Feil administrativt gjenopprettingspassord. Sjekk passordet og prøv igjen.",
    "Backend does not support password change, but the encryption of the account key was updated." : "Serveren støtter ikke passordendring, men krypteringen av kontonøkkelen ble oppdatert.",
    "Administrator documentation" : "Administratordokumentasjon",
    "User documentation" : "Brukerdokumentasjon",
    "Nextcloud help overview" : "Oversikt over hjelp for Nextcloud",
    "Invalid SMTP password." : "Ugyldig SMTP-passord.",
    "Email setting test" : "E-postinnstillingstest",
    "Well done, %s!" : "Bra gjort, %s!",
    "If you received this email, the email configuration seems to be correct." : "Hvis du mottar denne e-posten, er e-postoppsettet rett.",
    "Email could not be sent. Check your mail server log" : "E-post kunne ikke sendes. Sjekk serverloggen på din e-postserver",
    "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "Et problem oppsto med sending av e-post. Sjekk innstillingene. (Feil: %s)",
    "You need to set your account email before being able to send test emails. Go to %s for that." : "Du må angi konto-e-postadressen din før du kan sende test-e-post. Gå til %s for det.",
    "Recently active" : "Nylig aktiv",
    "Disabled accounts" : "Deaktiverte kontoer",
    "Invalid account" : "Ugyldig konto",
    "Invalid mail address" : "Ugyldig e-postadresse",
    "Settings saved" : "Innstillinger lagret",
    "Unable to change full name" : "Klarte ikke å endre fullt navn",
    "Unable to change email address" : "Klarer ikke å endre e-postadresse",
    "Unable to set invalid phone number" : "Kan ikke angi ugyldig telefonnummer",
    "Unable to set invalid website" : "Kan ikke angi ugyldig nettsted",
    "Some account data was invalid" : "Noen kontodata var ugyldige",
    "In order to verify your Twitter account, post the following tweet on Twitter (please make sure to post it without any line breaks):" : "For å bekrefte din Twitter-konto, post følgende tvitring på Twitter (pass på å ikke få med noen linjeskift):",
    "In order to verify your Website, store the following content in your web-root at '.well-known/CloudIdVerificationCode.txt' (please make sure that the complete text is in one line):" : "For å bekrefte din nettside, lagre følgende innhold på roten av din netserver på '.well-known/CloudIdVerificationCode.txt' (forsikre deg om at hele teksten er på ei linje):",
    "%1$s changed your password on %2$s." : "%1$s endret ditt passord på %2$s.",
    "Your password on %s was changed." : "Ditt passord på %s ble endret.",
    "Your password on %s was reset by an administrator." : "Passordet ditt på %s ble tilbakestilt av en administrator.",
    "Your password on %s was reset." : "Ditt passord på %s ble nullstilt.",
    "Password for %1$s changed on %2$s" : "Passord for %1$s endret på %2$s",
    "Password changed for %s" : "Passord endret for %s",
    "If you did not request this, please contact an administrator." : "Hvis du ikke forespurte dette, kontakt en administrator.",
    "Your email address on %s was changed." : "Din e-postadresse på %s ble endret.",
    "Your email address on %s was changed by an administrator." : "Din e-postadresse på %s ble endret av en administrator.",
    "Email address for %1$s changed on %2$s" : "E-postadresse for %1$s endret på %2$s",
    "Email address changed for %s" : "E-postadresse endret for %s",
    "The new email address is %s" : "Den nye e-postadressen er %s",
    "Your %s account was created" : "%s-kontoen din ble opprettet",
    "Welcome aboard" : "Velkommen ombord",
    "Welcome aboard %s" : "Velkommen ombord i %s",
    "Welcome to your %s account, you can add, protect, and share your data." : "Velkommen til din %s-konto, du kan legge til, beskytte og dele din data.",
    "Your Login is: %s" : "Din pålogging er: %s",
    "Set your password" : "Sett passordet ditt",
    "Go to %s" : "Gå til %s",
    "Install Client" : "Installer klient",
    "Apps" : "Apper",
    "Personal" : "Personlig",
    "Administration" : "Administrasjon",
    "Users" : "Brukere",
    "Additional settings" : "Flere innstillinger",
    "Assistant" : "Assistent",
    "Administration privileges" : "Administratorrettigheter",
    "Groupware" : "Gruppevare",
    "Overview" : "Oversikt",
    "Basic settings" : "Grunninnstillinger",
    "Sharing" : "Deling",
    "Availability" : "Tilgjengelighet",
    "Calendar" : "Kalender",
    "Personal info" : "Personlig informasjon",
    "Mobile & desktop" : "Mobil og skrivebord",
    "Artificial Intelligence" : "Kunstig intelligens",
    "Email server" : "E-postserver",
    "Mail Providers" : "Epost-tilbydere",
    "Mail provider enables sending emails directly through the user's personal email account. At present, this functionality is limited to calendar invitations. It requires Nextcloud Mail 4.1 and an email account in Nextcloud Mail that matches the user's email address in Nextcloud." : "Epost-tilbyder åpner for sending av epost direkte via brukerens personlige epost-konto. På nåværende tidspunkt er denne funskjonen begrenset til kalenderinvitasjoner. Krever Nextcloud Mail 4.1 og en epost-konto i Nextcloud Mail som er lik brukerens epost-adresse i Nextcloud.",
    "Send emails using" : "Send eposter med",
    "User's email account" : "Brukerens epost-konto",
    "System email account" : "Systemets epost-konto",
    "Background jobs" : "Bakgrunnsjobber",
    "Unlimited" : "Ubegrenset",
    "Verifying" : "Verifiserer",
    "Allowed admin IP ranges" : "Tillatte IP-områder for administrator",
    "Configuration key \"%1$s\" expects an array (%2$s found). Admin IP range validation will not be applied." : "Konfigurasjonsnøkkel \"%1$s\" forventer en nøkkel (%2$s funnet). Validering av IP-området for administrator blir ikke anvendt.",
    "Configuration key \"%1$s\" contains invalid IP range(s): \"%2$s\"" : "Konfigurasjonsnøkkel \"%1$s\" inneholder ugyldig(e) IP-område(r): \"%2$s\"",
    "Admin IP filtering is correctly configured." : "Administrator IP-filtrering er riktig konfigurert.",
    "App directories owner" : "Eier av appkataloger",
    "Some app directories are owned by a different user than the web server one. This may be the case if apps have been installed manually. Check the permissions of the following app directories:\n%s" : "Enkelte mapper er eid av annen bruker enn den webserveren kjører som. Dette kan kan oppstå hvis apper er installert manuelt. Sjekk eierskap og tillatelser på følgende appkataloger:\n%s",
    "App directories have the correct owner \"%s\"" : "Appkataloger har riktig eier \"%s\"",
    "Brute-force Throttle" : "rå makt struping",
    "Your remote address could not be determined." : "Den eksterne adressen din kunne ikke fastslås.",
    "Your remote address was identified as \"%s\" and is brute-force throttled at the moment slowing down the performance of various requests. If the remote address is not your address this can be an indication that a proxy is not configured correctly." : "Din eksterne adresse ble identifisert som \"%s\" og er rå makt-strupet for øyeblikket, noe som reduserer ytelsen til forskjellige forespørsler. Hvis den eksterne adressen ikke er adressen din, kan dette være en indikasjon på at en proxy ikke er riktig konfigurert.",
    "Your remote address \"%s\" is not brute-force throttled." : "Din eksterne adresse \"%s\" er ikke rå makt-strupet.",
    "Old administration imported certificates" : "Gamle administrasjonsimporterte sertifikater",
    "A background job is pending that checks for administration imported SSL certificates. Please check back later." : "Det venter en bakgrunnsjobb som ser etter administrasjonsimporterte SSL-sertifikater. Kom tilbake senere.",
    "There are some administration imported SSL certificates present, that are not used anymore with Nextcloud 21. They can be imported on the command line via \"occ security:certificates:import\" command. Their paths inside the data directory are shown below." : "Det er noen administrasjonsimporterte SSL-sertifikater til stede, som ikke brukes lenger med Nextcloud 21. De kan importeres på kommandolinjen via kommandoen \"occ security:certificates:import\". Stiene deres i datakatalogen vises nedenfor.",
    "Code integrity" : "Kodeintegritet",
    "Integrity checker has been disabled. Integrity cannot be verified." : "Integritetskontrollen er deaktivert. Integritet kan ikke verifiseres.",
    "No altered files" : "Ingen endrede filer",
    "Some files have not passed the integrity check. {link1} {link2}" : "Noen filer har ikke bestått integritetskontrollen. {link1} {link2}",
    "Cron errors" : "Cron-feil",
    "It was not possible to execute the cron job via CLI. The following technical errors have appeared:\n%s" : "Det var ikke mulig å utføre cron-jobben via CLI. Følgende tekniske feil har dukket opp:\n%s",
    "The last cron job ran without errors." : "Den siste cron-jobben kjørte uten feil.",
    "Cron last run" : "Siste cron-kjøring",
    "Last background job execution ran %s. Something seems wrong. {link}." : "Siste bakgrunnsjobbkjøring kjørte %s. Noe virker galt. {link}.",
    "Last background job execution ran %s." : "Siste bakgrunnsjobbkjøring kjørte %s. ",
    "Data directory protected" : "Datakatalog beskyttet",
    "Your data directory and files are probably accessible from the internet. The .htaccess file is not working. It is strongly recommended that you configure your web server so that the data directory is no longer accessible, or move the data directory outside the web server document root." : "Datakatalogen og filene dine er sannsynligvis tilgjengelige fra internett. .htaccess-filen fungerer ikke. Det anbefales på det sterkeste at du konfigurerer webserveren slik at datakatalogen ikke lenger er tilgjengelig, eller flytter datakatalogen utenfor webserverens dokumentrot.",
    "Could not check that the data directory is protected. Please check manually that your server does not allow access to the data directory." : "Kan ikke kontrollere at datakatalogen er beskyttet. Kontroller manuelt at serveren din ikke tillater tilgang til datakatalogen.",
    "Database missing columns" : "Database mangler kolonner",
    "Missing optional column \"%s\" in table \"%s\"." : "Mangler valgfri kolonne \"%s\" i tabell \"%s\".",
    "The database is missing some optional columns. Due to the fact that adding columns on big tables could take some time they were not added automatically when they can be optional. By running \"occ db:add-missing-columns\" those missing columns could be added manually while the instance keeps running. Once the columns are added some features might improve responsiveness or usability." : "Databasen mangler noen valgfrie kolonner. Å legge til kolonner på store tabeller kan ta lang tid, så de ble ikke lagt til automatisk, ettersom de er valgfrie. Ved å kjøre \"occ db:add-missing-columns\" legges de manglende kolonnene til mens tjenesten fortsatt er tilgjengelig. Noen funksjoner kan få økt respons eller brukervennlighet når kolonnene er lagt til.",
    "Database missing indices" : "Database mangler indekser",
    "Missing indices:" : "Manglende indekser:",
    "\"%s\" in table \"%s\"" : "\"%s\" i tabell \"%s\"",
    "Database missing primary keys" : "Database mangler primærnøkler",
    "Missing primary key on table \"%s\"." : "Mangler primærnøkkel på tabellen \"%s\".",
    "The database is missing some primary keys. Due to the fact that adding primary keys on big tables could take some time they were not added automatically. By running \"occ db:add-missing-primary-keys\" those missing primary keys could be added manually while the instance keeps running." : "Databasen mangler noen primærnøkler. På grunn av det faktum at det kan ta litt tid å legge til primærnøkler på store bord, ble de ikke lagt til automatisk. Ved å kjøre \"occ db:add-missing-primary-keys\" kan de manglende primærnøklene legges til manuelt mens forekomsten fortsetter å kjøre.",
    "Database pending bigint migrations" : "Database venter på bigint-overføringer",
    "Some columns in the database are missing a conversion to big int. Due to the fact that changing column types on big tables could take some time they were not changed automatically. By running \"occ db:convert-filecache-bigint\" those pending changes could be applied manually. This operation needs to be made while the instance is offline." : "Noen kolonner i databasen mangler en konvertering til big int. På grunn av det faktum at endring av kolonnetyper på store tabeller kunne ta litt tid ble de ikke endret automatisk. Ved å kjøre \"occ db:convert-filecache-bigint\" kan de ventende endringene anvendes manuelt. Denne operasjonen må utføres mens forekomsten er frakoblet.",
    "Debug mode" : "Feilsøkingsmodus",
    "This instance is running in debug mode. Only enable this for local development and not in production environments." : "Denne forekomsten kjører i feilsøkingsmodus. Bare aktiver dette for lokal utvikling og ikke i produksjonsmiljøer.",
    "Debug mode is disabled." : "Feilsøkingsmodus er deaktivert.",
    "Default phone region" : "Standard region for telefon",
    "Your installation has no default phone region set. This is required to validate phone numbers in the profile settings without a country code. To allow numbers without a country code, please add \"default_phone_region\" with the respective ISO 3166-1 code of the region to your config file." : "Installasjonen har ingen standard telefonregion angitt. Dette kreves for å validere telefonnumre i profilinnstillingene uten landskode. Hvis du vil tillate numre uten landskode, må du legge til \"default_phone_region\" med den respektive ISO 3166-1-koden for regionen i konfigurasjonsfilen.",
    "Email test" : "Test av e-post",
    "Email test was successfully sent" : "E-posttesten ble sendt",
    "You have not set or verified your email server configuration, yet. Please head over to the \"Basic settings\" in order to set them. Afterwards, use the \"Send email\" button below the form to verify your settings." : "Du har ikke angitt eller bekreftet konfigurasjonen av e-postserveren ennå. Gå over til \"Grunnleggende innstillinger\" for å angi dem. Etterpå bruker du \"Send e-post\" -knappen under skjemaet for å bekrefte innstillingene dine.",
    "Transactional File Locking" : "Transaksjonsfillåsing",
    "Transactional File Locking is disabled. This is not a a supported configuraton. It may lead to difficult to isolate problems including file corruption. Please remove the `'filelocking.enabled' => false` configuration entry from your `config.php` to avoid these problems." : "Transaksjonsfillåsing er deaktivert. Dette er ikke en støttet konfigurasjon. Det kan føre til problemer som er vanskelige å isolere, inkludert filkorrupsjon. Vennligst fjern '''filelocking.enabled' => false\"-konfigurasjonsoppføringen fra 'config.php' for å unngå disse problemene.",
    "The database is used for transactional file locking. To enhance performance, please configure memcache, if available." : "Databasen brukes til låsing av transaksjonsfiler. For å forbedre ytelsen, vennligst konfigurer memcache, hvis tilgjengelig.",
    "Forwarded for headers" : "Forwarded-For headers",
    "Your \"trusted_proxies\" setting is not correctly set, it should be an array." : "\"trusted_proxies\"-innstillingen din er ikke riktig angitt, den bør være en matrise.",
    "Your \"trusted_proxies\" setting is not correctly set, it should be an array of IP addresses - optionally with range in CIDR notation." : "Innstillingen \"trusted_proxies\" er ikke riktig innstilt, den skal være en rekke IP-adresser - eventuelt med rekkevidde i CIDR-notasjon.",
    "The reverse proxy header configuration is incorrect. This is a security issue and can allow an attacker to spoof their IP address as visible to the Nextcloud." : "Konfigurasjonen av omvendt proxy-header er feil. Dette er et sikkerhetsproblem og kan gjøre det mulig for en angriper å etterligne IP-adressen sin som synlig for Nextcloud.",
    "Your IP address was resolved as %s" : "IP-adressen din ble løst som %s",
    "The reverse proxy header configuration is incorrect, or you are accessing Nextcloud from a trusted proxy. If not, this is a security issue and can allow an attacker to spoof their IP address as visible to the Nextcloud." : "Oppsettet for omvendt proxy-header er feil, eller du får tilgang til Nextcloud fra en pålitelig proxy. Hvis ikke, er dette et sikkerhetsproblem og kan tillate en angriper å forfalske IP-adressen sin som synlig for Nextcloud.",
    "HTTPS access and URLs" : "HTTPS-tilgang og URL-er",
    "Accessing site insecurely via HTTP. You are strongly advised to set up your server to require HTTPS instead. Without it some important web functionality like \"copy to clipboard\" or \"service workers\" will not work!" : "Du får tilgang til nettstedet usikkert via HTTP. Du anbefales på det sterkeste å konfigurere serveren din til å kreve HTTPS i stedet. Uten det vil noen viktige webfunksjoner som \"kopier til utklippstavlen\" eller \"tjenestearbeidere\" ikke fungere!",
    "Accessing site insecurely via HTTP." : "Får tilgang til nettstedet på en usikker måte via HTTP.",
    "You are accessing your instance over a secure connection, however your instance is generating insecure URLs. This likely means that your instance is behind a reverse proxy and the Nextcloud `overwrite*` config values are not set correctly." : "Du får tilgang til forekomsten via en sikker tilkobling, men forekomsten genererer usikre URL-adresser. Dette betyr sannsynligvis at forekomsten din er bak en omvendt proxy og Nextcloud 'overwrite*' konfigurasjonsverdier ikke er riktig angitt.",
    "Your instance is generating insecure URLs. If you access your instance over HTTPS, this likely means that your instance is behind a reverse proxy and the Nextcloud `overwrite*` config values are not set correctly." : "Forekomsten genererer usikre URL-adresser. Hvis du får tilgang til forekomsten din via HTTPS, betyr dette sannsynligvis at forekomsten din er bak en omvendt proxy og Nextcloud 'overwrite*' konfigurasjonsverdier ikke er riktig angitt.",
    "You are accessing your instance over a secure connection, and your instance is generating secure URLs." : "Du får tilgang til forekomsten via en sikker tilkobling, og forekomsten genererer sikre nettadresser.",
    "Internet connectivity" : "Internett-tilkobling",
    "Internet connectivity is disabled in configuration file." : "Internett-tilkobling er deaktivert i konfigurasjonsfilen.",
    "This server has no working internet connection: Multiple endpoints could not be reached. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. Establish a connection from this server to the internet to enjoy all features." : "Denne serveren har ingen fungerende internettforbindelse: Flere endepunkter kunne ikke nås. Dette betyr at noen av funksjonene som montering av ekstern lagring, varsler om oppdateringer eller installasjon av tredjepartsapper ikke vil fungere. Tilgang til filer eksternt og sending av e-postvarsler fungerer kanskje heller ikke. Etabler en tilkobling fra denne serveren til internett for å nyte alle funksjonene.",
    "JavaScript modules support" : "Støtte for JavaScript-moduler",
    "Unable to run check for JavaScript support. Please remedy or confirm manually if your webserver serves `.mjs` files using the JavaScript MIME type." : "Kunne ikke se etter JavaScript-støtte. Kontroller manuelt om webserveren din tilbyr '.mjs'-filer ved hjelp av JavaScript MIME-typen.",
    "Your webserver does not serve `.mjs` files using the JavaScript MIME type. This will break some apps by preventing browsers from executing the JavaScript files. You should configure your webserver to serve `.mjs` files with either the `text/javascript` or `application/javascript` MIME type." : "Webserveren din serverer ikke '.mjs'-filer ved hjelp av JavaScript MIME-typen. Dette vil ødelegge noen apper ved å hindre nettlesere i å kjøre JavaScript-filene. Du bør konfigurere webserveren din til å betjene '.mjs' filer med enten 'text/javascript' eller 'application/javascript' MIME-type.",
    "JavaScript source map support" : "Støtte for JavaScript source map",
    "Your webserver is not set up to serve `.js.map` files. Without these files, JavaScript Source Maps won't function properly, making it more challenging to troubleshoot and debug any issues that may arise." : "Webserveren din er ikke konfigurert til å betjene '.js.map'-filer. Uten disse filene fungerer ikke JavaScript-kildekart som de skal, noe som gjør det mer utfordrende å feilsøke og feilsøke eventuelle problemer som kan oppstå.",
    "Old server-side-encryption" : "Gammel server-side-kryptering",
    "Disabled" : "Deaktivert",
    "The old server-side-encryption format is enabled. We recommend disabling this." : "Den gamle server-side-kryptering er aktivert. Vi anbefaler å deaktivere dette.",
    "Maintenance window start" : "Vedlikeholdsvindu start",
    "Server has no maintenance window start time configured. This means resource intensive daily background jobs will also be executed during your main usage time. We recommend to set it to a time of low usage, so users are less impacted by the load caused from these heavy tasks." : "Serveren har ikke konfigurert noe vedlikeholdsvindu starttid. Dette betyr at ressurskrevende daglige bakgrunnsjobber også vil bli utført i løpet av hovedbrukstiden. Vi anbefaler at du setter den til en tid med lite bruk, slik at brukerne blir mindre påvirket av belastningen forårsaket av disse tunge oppgavene.",
    "Maintenance window to execute heavy background jobs is between {start}:00 UTC and {end}:00 UTC" : "Vedlikeholdsvindu for å utføre tunge bakgrunnsjobber er mellom {start}:00 UTC og {end}:00 UTC",
    "Memcache" : "Memcache",
    "Memcached is configured as distributed cache, but the wrong PHP module (\"memcache\") is installed. Please install the PHP module \"memcached\"." : "Memcached er konfigurert som distribuert hurtigbuffer, men feil PHP-modul (\"memcache\") er installert. Vennligst installer PHP-modulen \"memcached\".",
    "Memcached is configured as distributed cache, but the PHP module \"memcached\" is not installed. Please install the PHP module \"memcached\"." : "Memcached er konfigurert som distribuert hurtigbuffer, men PHP-modulen \"memcached\" er ikke installert. Vennligst installer PHP-modulen \"memcached\".",
    "No memory cache has been configured. To enhance performance, please configure a memcache, if available." : "Ingen minnebuffer er konfigurert. For å forbedre ytelsen, vennligst konfigurer en memcache, hvis tilgjengelig.",
    "Configured" : "Konfigurert",
    "Mimetype migrations available" : "Mimetype-migreringer tilgjengelig",
    "One or more mimetype migrations are available. Occasionally new mimetypes are added to better handle certain file types. Migrating the mimetypes take a long time on larger instances so this is not done automatically during upgrades. Use the command `occ maintenance:repair --include-expensive` to perform the migrations." : "Én eller flere mimetypemigreringer er tilgjengelige. Av og til blir nye mimetyper lagt til for bedre å håndtere visse filtyper. Migrering av mimetypene tar lang tid på større forekomster, så dette gjøres ikke automatisk under oppgraderinger. Bruk kommandoen 'occ maintenance: repair --include-expensive' for å utføre migreringene.",
    "MySQL row format" : "MySQL-radformat",
    "You are not using MySQL" : "Du bruker ikke MySQL",
    "MySQL Unicode support" : "MySQL unicode-støtte",
    "MySQL is used as database and does support 4-byte characters" : "MySQL brukes som database og støtter 4-byte tegn",
    "MySQL is used as database but does not support 4-byte characters. To be able to handle 4-byte characters (like emojis) without issues in filenames or comments for example it is recommended to enable the 4-byte support in MySQL." : "MySQL brukes som database, men støtter ikke 4-byte-tegn. For å kunne håndtere 4-byte-tegn (som emojis) uten problemer i filnavn eller kommentarer, anbefales det for eksempel å aktivere 4-byte-støtten i MySQL.",
    "OCS provider resolving" : "OCS-leverandør løsing",
    "Could not check if your web server properly resolves the OCM and OCS provider URLs." : "Kunne ikke sjekke om webserveren din løser nettadressene til OCM og OCS-leverandøren på riktig måte.",
    "Your web server is not properly set up to resolve %1$s.\nThis is most likely related to a web server configuration that was not updated to deliver this folder directly.\nPlease compare your configuration against the shipped rewrite rules in \".htaccess\" for Apache or the provided one in the documentation for Nginx.\nOn Nginx those are typically the lines starting with \"location ~\" that need an update." : "Nettserveren din er ikke riktig konfigurert for å løse %1$s.\nDette er mest sannsynlig relatert til en webserverkonfigurasjon som ikke ble oppdatert for å levere denne mappen direkte.\nSammenlign konfigurasjonen din med de tilsendte omskrivingsreglene i \".htaccess\" for Apache eller den oppgitte i dokumentasjonen for Nginx.\nPå Nginx er det vanligvis linjene som starter med \"location ~\" som trenger en oppdatering.",
    "Overwrite CLI URL" : "Overwrite CLI URL",
    "The \"overwrite.cli.url\" option in your config.php is correctly set to \"%s\"." : "\"overwrite.cli.url\"-alternativet i din config.php er korrekt angitt til \"%s\".",
    "The \"overwrite.cli.url\" option in your config.php is set to \"%s\" which is a correct URL. Suggested URL is \"%s\"." : "\"overwrite.cli.url\"-alternativet i din config.php er angitt til \"%s\", som er en korrekt URL. Foreslått URL er \"%s\".",
    "Please make sure to set the \"overwrite.cli.url\" option in your config.php file to the URL that your users mainly use to access this Nextcloud. Suggestion: \"%s\". Otherwise there might be problems with the URL generation via cron. (It is possible though that the suggested URL is not the URL that your users mainly use to access this Nextcloud. Best is to double check this in any case.)" : "Sørg for å sette alternativet \"overwrite.cli.url\" i config.php filen til URL-en som brukerne dine hovedsakelig bruker for å få tilgang til denne Nextcloud. Forslag: \"%s\". Ellers kan det være problemer med URL-genereringen via cron. (Det er imidlertid mulig at den foreslåtte nettadressen ikke er nettadressen som brukerne dine hovedsakelig bruker for å få tilgang til denne Nextcloud. Beste er å dobbeltsjekke dette i alle fall).",
    "PHP APCu configuration" : "PHP APCu-konfigurasjon",
    "Your APCu cache has been running full, consider increasing the apc.shm_size php setting." : "APCu-bufferen din har vært full, vurder å øke apc.shm_size php-innstillingen.",
    "Your APCu cache is almost full at %s%%, consider increasing the apc.shm_size php setting." : "APCu-bufferen din er nesten full på %s%%, vurder å øke apc.shm_size php-innstillingen.",
    "PHP default charset" : "PHP default charset (standard tegnsett)",
    "PHP configuration option \"default_charset\" should be UTF-8" : "PHP-konfigurasjonsalternativ \"default_charset\" bør være UTF-8",
    "PHP set_time_limit" : "PHP set_time_limit",
    "The function is available." : "Funksjonen er tilgjengelig.",
    "The PHP function \"set_time_limit\" is not available. This could result in scripts being halted mid-execution, breaking your installation. Enabling this function is strongly recommended." : "PHP-funksjonen \"set_time_limit\" er ikke tilgjengelig. Dette kan resultere i at skript blir stoppet midt i kjøring, noe som knekker installasjonen din. Det anbefales sterkt å skru på denne funksjonen.",
    "Freetype" : "Freetype",
    "Supported" : "Støttet",
    "Your PHP does not have FreeType support, resulting in breakage of profile pictures and the settings interface." : "Din PHP-installasjon har ikke FreeType-støtte. Dette fører til knekte profilbilder og skadelidende innstillingsgrensesnitt.",
    "PHP getenv" : "PHP getenv",
    "PHP does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "PHP er satt opp feil for å nå systemets miljøvariable. Test med getenv(\"PATH\") gir tom respons.",
    "PHP memory limit" : "PHP-minnegrense",
    "PHP modules" : "PHP-moduler",
    "increases language translation performance and fixes sorting of non-ASCII characters" : "øker ytelsen til oversettelse av språk og løser sortering av ikke-ASCII-tegn",
    "for Argon2 for password hashing" : "for Argon2 for hashing av passord",
    "for picture rotation in server and metadata extraction in the Photos app" : "for bilderotasjon i server og metadatauttrekking i Photos-appen",
    "This instance is missing some required PHP modules. It is required to install them: %s." : "Denne forekomsten mangler noen nødvendige PHP-moduler. Det kreves å installere dem: %s.",
    "This instance is missing some recommended PHP modules. For improved performance and better compatibility it is highly recommended to install them:\n%s" : "Denne forekomsten mangler noen anbefalte PHP-moduler. For forbedret ytelse og bedre kompatibilitet anbefales det sterkt å installere dem:\n%s",
    "PHP opcache" : "PHP opcache",
    "The PHP OPcache module is not loaded. For better performance it is recommended to load it into your PHP installation." : "PHP OPcache-modulen er ikke lastet. For bedre ytelse anbefales det å laste den inn i PHP-installasjonen.",
    "OPcache is disabled. For better performance, it is recommended to apply \"opcache.enable=1\" to your PHP configuration." : "OPcache er deaktivert. For bedre ytelse anbefales det å bruke \"opcache.enable=1\" på PHP-konfigurasjonen.",
    "The shared memory based OPcache is disabled. For better performance, it is recommended to apply \"opcache.file_cache_only=0\" to your PHP configuration and use the file cache as second level cache only." : "Den delte minnebaserte OPcache er deaktivert. For bedre ytelse anbefales det å bruke \"opcache.file_cache_only=0\" på PHP-konfigurasjonen og bare bruke filbufferen som filbuffer på andre nivå.",
    "OPcache is not working as it should, opcache_get_status() returns false, please check configuration." : "OPcache fungerer ikke som det skal, opcache_get_status() returnerer usann, vennligst sjekk konfigurasjonen.",
    "The maximum number of OPcache keys is nearly exceeded. To assure that all scripts can be kept in the cache, it is recommended to apply \"opcache.max_accelerated_files\" to your PHP configuration with a value higher than \"%s\"." : "Maksimalt antall OPcache-nøkler overskrides nesten. For å sikre at alle skript kan holdes i hurtigbufferen, anbefales det å bruke \"opcache.max_accelerated_files\" på PHP-konfigurasjonen med en verdi høyere enn \"%s\".",
    "The OPcache buffer is nearly full. To assure that all scripts can be hold in cache, it is recommended to apply \"opcache.memory_consumption\" to your PHP configuration with a value higher than \"%s\"." : "OPcache-bufferen er nesten full. For å sikre at alle skript kan holdes i hurtigbufferen, anbefales det å bruke \"opcache.memory_consumption\" på PHP-konfigurasjonen med en verdi høyere enn \"%s\".",
    "The OPcache interned strings buffer is nearly full. To assure that repeating strings can be effectively cached, it is recommended to apply \"opcache.interned_strings_buffer\" to your PHP configuration with a value higher than \"%s\"." : "OPcache-internerte strengbufferen er nesten full. For å sikre at gjentatte strenger kan bufres effektivt, anbefales det å bruke \"opcache.interned_strings_buffer\" på PHP-konfigurasjonen med en verdi høyere enn \"%s\".",
    "OPcache is configured to remove code comments. With OPcache enabled, \"opcache.save_comments=1\" must be set for Nextcloud to function." : "OPcache er konfigurert til å fjerne kodekommentarer. Når OPcache er aktivert, må \"opcache.save_comments=1\" settes for at Nextcloud skal fungere.",
    "Nextcloud is not allowed to use the OPcache API. With OPcache enabled, it is highly recommended to include all Nextcloud directories with \"opcache.restrict_api\" or unset this setting to disable OPcache API restrictions, to prevent errors during Nextcloud core or app upgrades." : "Nextcloud har ikke tillatelse til å bruke OPcache API. Når OPcache er aktivert, anbefales det sterkt å inkludere alle Nextcloud-kataloger med \"opcache.restrict_api\" eller fjerne denne innstillingen for å deaktivere OPcache API-begrensninger for å forhindre feil under Nextcloud-kjerne- eller appoppgraderinger.",
    "Checking from CLI, OPcache checks have been skipped." : "Kontroll fra CLI, OPcache-sjekker er hoppet over.",
    "The PHP OPcache module is not properly configured. %s." : "PHP OPcache-modulen er ikke riktig konfigurert. %s.",
    "Correctly configured" : "Korrekt konfigurert",
    "PHP version" : "PHP-versjon",
    "You are currently running PHP %s." : "Du kjører for øyeblikket PHP %s.",
    "PHP \"output_buffering\" option" : "PHP \"output_buffering\"-alternativ",
    "PHP configuration option \"output_buffering\" must be disabled" : "PHP-konfigurasjonsalternativ \"output_buffering\" må være deaktivert",
    "Push service" : "Push-tjeneste",
    "Valid enterprise license" : "Gyldig enterprise-lisens",
    "Free push service" : "Gratis push-tjeneste",
    "This is the unsupported community build of Nextcloud. Given the size of this instance, performance, reliability and scalability cannot be guaranteed. Push notifications are limited to avoid overloading our free service. Learn more about the benefits of Nextcloud Enterprise at {link}." : "Dette er den ikke-støttede fellesskapsbyggingen av Nextcloud. Gitt størrelsen på denne forekomsten, kan ikke ytelse, pålitelighet og skalerbarhet garanteres. Push-varsler er begrenset for å unngå overbelastning av gratistjenesten vår. Les mer om fordelene med Nextcloud Enterprise på {link}.",
    "Random generator" : "Tilfeldig generator",
    "No suitable source for randomness found by PHP which is highly discouraged for security reasons." : "Ingen passende kilde for tilfeldighet funnet av PHP, som er sterkt frarådd av sikkerhetsgrunner.",
    "Secure" : "Sikker",
    "Configuration file access rights" : "Tilgangsrettigheter for konfigurasjonsfil",
    "The read-only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "Ikke skrivbar konfigurasjon er aktivert. Dette hindrer endring av konfigurasjon via web-grensesnitt. Filen må gjøres skrivbar manuelt for hver oppdatering.",
    "Nextcloud configuration file is writable" : "Nextcloud-konfigurasjonsfilen er skrivbar",
    "Scheduling objects table size" : "Planlegge objekter tabellstørrelse",
    "You have more than %s rows in the scheduling objects table. Please run the expensive repair jobs via occ maintenance:repair --include-expensive." : "Du har mer enn %s rader i tabellen 'scheduling objects'. Kjør reparasjonsjobbene 'expensive' via occ maintenance:repair --include-expensive",
    "Scheduling objects table size is within acceptable range." : "'Scheduling objects'-tabellstørrelsen er innenfor akseptabelt område.",
    "HTTP headers" : "HTTP-hoder",
    "- The `%1$s` HTTP header is not set to `%2$s`. Some features might not work correctly, as it is recommended to adjust this setting accordingly." : "- HTTP-hodet '%1$s'  er ikke satt til '%2$s'. Noen funksjoner fungerer kanskje ikke som de skal, da det anbefales å justere denne innstillingen tilsvarende.",
    "- The `%1$s` HTTP header is not set to `%2$s`. This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "- HTTP-hodet '%1$s' er ikke satt til '%2$s'.  Dette er en potensiell sikkerhets- eller personvernrisiko, da det anbefales å justere denne innstillingen tilsvarende.",
    "- The `%1$s` HTTP header is not set to `%2$s`, `%3$s`, `%4$s`, `%5$s` or `%6$s`. This can leak referer information. See the {w3c-recommendation}." : "- HTTP-hodet '%1$s' er ikke satt til  '%2$s', '%3$s', '%4$s', '%5$s' eller '%6$s'. Dette kan lekke referanseinformasjon. Se {w3c-recommendation}.",
    "- The `Strict-Transport-Security` HTTP header is not set to at least `%d` seconds (current value: `%d`). For enhanced security, it is recommended to use a long HSTS policy." : "HTTP-hodet 'Strict-Transport-Security' er ikke satt til minst '%d' sekunder (gjeldende verdi: '%d'). For økt sikkerhet anbefales det å bruke en lang HSTS-policy.",
    "- The `Strict-Transport-Security` HTTP header is malformed: `%s`. For enhanced security, it is recommended to enable HSTS." : "- HTTP-hodet 'Strict-Transport-Security' er misformet: '%s'. For forbedret sikkerhet anbefales det å aktivere HSTS.",
    "- The `Strict-Transport-Security` HTTP header is not set (should be at least `%d` seconds). For enhanced security, it is recommended to enable HSTS." : "- HTTP-hodet 'Strict-Transport-Security' er ikke angitt (bør minst være '%d' sekunder). For forbedret sikkerhet anbefales det å aktivere HSTS.",
    "Some headers are not set correctly on your instance" : "Noen http-hoder er ikke korrekt satt opp på din forekomst",
    "Could not check that your web server serves security headers correctly. Please check manually." : "Kunne ikke sjekke at webserveren din betjener 'security headers' riktig. Vennligst sjekk manuelt.",
    "Could not check that your web server serves security headers correctly, unable to query `%s`" : "Kunne ikke sjekke at webserveren din betjener 'security headers' riktig, ikke i stand til å spørre '%s'.",
    "Your server is correctly configured to send security headers." : "Serveren er riktig konfigurert til å sende sikkerhetshoder.",
    "Database version" : "Databaseversjon",
    "MariaDB version 10.3 detected, this version is end-of-life and only supported as part of Ubuntu 20.04. MariaDB >=%1$s and <=%2$s is suggested for best performance, stability and functionality with this version of Nextcloud." : "MariaDB-versjon 10.3 oppdaget, denne versjonen har nådd slutten av levetiden og støttes bare som en del av Ubuntu 20.04. MariaDB >=%1$s og <=%2$s foreslås for best ytelse, stabilitet og funksjonalitet med denne versjonen av Nextcloud.",
    "MariaDB version \"%1$s\" detected. MariaDB >=%2$s and <=%3$s is suggested for best performance, stability and functionality with this version of Nextcloud." : "MariaDB-versjon \"%1$s\" oppdaget. MariaDB >=%2$s og <=%3$s foreslås for best ytelse, stabilitet og funksjonalitet med denne versjonen av Nextcloud.",
    "MySQL version \"%1$s\" detected. MySQL >=%2$s and <=%3$s is suggested for best performance, stability and functionality with this version of Nextcloud." : "MySQL-versjon \"%1$s\" oppdaget. MySQL >=%2$s og <=%3$s foreslås for best ytelse, stabilitet og funksjonalitet med denne versjonen av Nextcloud.",
    "SQLite is currently being used as the backend database. For larger installations we recommend that you switch to a different database backend. This is particularly recommended when using the desktop client for file synchronisation. To migrate to another database use the command line tool: \"occ db:convert-type\"." : "SQLite brukes for tiden som backend-database. For større installasjoner anbefaler vi at du bytter til en annen database-backend. Dette anbefales spesielt når du bruker skrivebordsklienten til filsynkronisering. For å migrere til en annen database, bruk kommandolinjeverktøyet: \"occ db:convert-type\".",
    "Unknown database platform" : "Ukjent databaseplattform",
    "Architecture" : "Arkitektur",
    "64-bit" : "64-biter",
    "It seems like you are running a 32-bit PHP version. Nextcloud needs 64-bit to run well. Please upgrade your OS and PHP to 64-bit!" : "Det virker som om du kjører en 32-biters PHP-versjon. Nextcloud trenger 64-bit for å kjøre bra. Vennligst oppgrader OS og PHP til 64-bit!",
    "Temporary space available" : "Midlertidig plass tilgjengelig",
    "Error while checking the temporary PHP path - it was not properly set to a directory. Returned value: %s" : "Feil under kontroll av den midlertidige PHP-banen - den var ikke riktig satt til en katalog. Returnert verdi: %s.",
    "The PHP function \"disk_free_space\" is disabled, which prevents the check for enough space in the temporary directories." : "PHP-funksjonen \"disk_free_space\" er deaktivert, noe som forhindrer kontroll for nok plass i de midlertidige katalogene.",
    "Error while checking the available disk space of temporary PHP path or no free disk space returned. Temporary path: %s" : "Feil under kontroll av tilgjengelig diskplass på midlertidig PHP-bane eller ingen ledig diskplass returnert. Midlertidig bane: %s.",
    "- %.1f GiB available in %s (PHP temporary directory)" : "- %.1f GB tilgjengelig i %s (midlertidig PHP-katalog)",
    "- %.1f GiB available in %s (Nextcloud temporary directory)" : "- %.1f GB tilgjengelig i %s (midlertidig Nextcloud-katalog)",
    "Temporary directory is correctly configured:\n%s" : "Midlertidig katalog er riktig konfigurert:\n%s",
    "This instance uses an S3 based object store as primary storage, and has enough space in the temporary directory.\n%s" : "Denne forekomsten bruker et S3-basert objektlager som primær lagring, og har nok plass i den midlertidige mappen.\n%s",
    "This instance uses an S3 based object store as primary storage. The uploaded files are stored temporarily on the server and thus it is recommended to have 50 GiB of free space available in the temp directory of PHP. To improve this please change the temporary directory in the php.ini or make more space available in that path. \nChecking the available space in the temporary path resulted in %.1f GiB instead of the recommended 50 GiB. Path: %s" : "Denne forekomsten bruker et S3-basert objektlager som primær lagring. De opplastede filene lagres midlertidig på serveren, og det anbefales derfor å ha 50 GB ledig plass tilgjengelig i temp-katalogen til PHP. For å forbedre dette kan du endre den midlertidige katalogen i php.ini eller gjøre mer plass tilgjengelig i den banen. \nKontroll av ledig plass i den midlertidige banen resulterte i %.1f GB i stedet for de anbefalte 50 GB. Sti: %s",
    "Database transaction isolation level" : "Isolasjonsnivå for databasetransaksjoner",
    "Your database does not run with \"READ COMMITTED\" transaction isolation level. This can cause problems when multiple actions are executed in parallel." : "Din database bruker ikke \"READ COMMITTED\" som isoleringsnivå for transaksjoner. Dette kan gi feil når flere hendelser skjer i parallell. Se dokumentasjon for din database og aktiver \"READ COMMITTED\" i din database for å unngå feil. ",
    "Was not able to get transaction isolation level: %s" : "Klarte ikke å få transaksjonsisolasjonsnivå: %s",
    ".well-known URLs" : ".velkjente nettadresser",
    "`check_for_working_wellknown_setup` is set to false in your configuration, so this check was skipped." : "`check_for_working_wellknown_setup` er satt til usant i konfigurasjonen, så denne kontrollen ble hoppet over.",
    "Could not check that your web server serves `.well-known` correctly. Please check manually." : "Kunne ikke sjekke at webserveren din betjener '.well-known' riktig. Vennligst sjekk manuelt.",
    "Your web server is not properly set up to resolve `.well-known` URLs, failed on:\n`%s`" : "Webserveren er ikke riktig konfigurert til å løse problemet `.well-known` URL-er, feilet på:\n`%s`",
    "Your server is correctly configured to serve `.well-known` URLs." : "Serveren din er riktig konfigurert til å betjene `.well-known` URL-er.",
    "Font file loading" : "Innlasting av skriftfil",
    "Could not check for {extension} loading support. Please check manually if your webserver serves `.{extension}` files." : "Kunne ikke se etter {extension}-lastestøtte. Kontroller manuelt om webserveren din verter '.{extension}'-filer.",
    "Your web server is not properly set up to deliver .{extension} files. This is typically an issue with the Nginx configuration. For Nextcloud 15 it needs an adjustment to also deliver .{extension} files. Compare your Nginx configuration to the recommended configuration in our documentation." : "Nettserveren din er ikke riktig konfigurert til å levere {extension}-filer. Dette er vanligvis et problem med Nginx-konfigurasjonen. For Nextcloud 15 trenger den en justering for også å levere {extension}-filer. Sammenlign Nginx-konfigurasjonen din med den anbefalte konfigurasjonen i dokumentasjonen vår.",
    "Profile information" : "Profil-informasjon",
    "Profile picture, full name, email, phone number, address, website, Twitter, organisation, role, headline, biography, and whether your profile is enabled" : "Profilbilde, fullt navn, e-post, telefonnummer, adresse, nettsted, Twitter, organisasjon, rolle, overskrift, biografi og om profilen din er aktivert",
    "Nextcloud settings" : "Nextcloud innstillinger",
    "Unified task processing" : "Enhetlig oppgavebehandling",
    "AI tasks can be implemented by different apps. Here you can set which app should be used for which task." : "AI-oppgaver kan implementeres av forskjellige apper. Her kan du angi hvilken app som skal brukes til hvilken oppgave.",
    "Enable" : "Aktiver",
    "None of your currently installed apps provide Task processing functionality" : "Ingen av appene du installerte for øyeblikket, har oppgavebehandlingsfunksjonalitet",
    "Machine translation" : "Maskinoversettelse",
    "Machine translation can be implemented by different apps. Here you can define the precedence of the machine translation apps you have installed at the moment." : "Maskinoversettelse kan implementeres av forskjellige apper. Her kan du definere prioriteten til maskinoversettelsesappene du har installert for øyeblikket.",
    "Image generation" : "Bildegenerering",
    "Image generation can be implemented by different apps. Here you can set which app should be used." : "Bildegenerering kan implementeres av forskjellige apper. Her kan du angi hvilken app som skal brukes.",
    "None of your currently installed apps provide image generation functionality" : "Ingen av de installerte appene dine har bildegenereringsfunksjonalitet",
    "Text processing" : "Tekstbehandling",
    "Text processing tasks can be implemented by different apps. Here you can set which app should be used for which task." : "Tekstbehandlingsoppgaver kan implementeres av forskjellige apper. Her kan du angi hvilken app som skal brukes til hvilken oppgave.",
    "Task:" : "Oppgave:",
    "None of your currently installed apps provide text processing functionality using the Text Processing API." : "Ingen av de installerte appene dine har tekstbehandlingsfunksjonalitet ved hjelp av API-en for tekstbehandling.",
    "Here you can decide which group can access certain sections of the administration settings." : "Her kan du bestemme hvilken gruppe som kan få tilgang til bestemte deler av administrasjonsinnstillingene.",
    "Unable to modify setting" : "Kan ikke endre innstilling",
    "None" : "Ingen",
    "Changed disclaimer text" : "Endret ansvarsfraskrivelse tekst",
    "Deleted disclaimer text" : "Slettet ansvarsfraskrivelse tekst",
    "Could not set disclaimer text" : "Kunne ikke angi ansvarsfraskrivelse tekst",
    "Allow apps to use the Share API" : "Tillat apper å bruke API for deling",
    "Allow resharing" : "TIllat videre deling",
    "Allow sharing with groups" : "Tillat deling med grupper",
    "Restrict users to only share with users in their groups" : "Begrens brukere til kun å dele med brukere i deres grupper",
    "Ignore the following groups when checking group membership" : "Ignorer følgende grupper når man sjekker gruppemedlemskap",
    "Allow users to share via link and emails" : "Tillat brukere å dele via lenker og e-poster",
    "Allow public uploads" : "Tillat offentlig opplasting",
    "Always ask for a password" : "Alltid spør om passord",
    "Enforce password protection" : "Krev passordbeskyttelse",
    "Exclude groups from password requirements" : "Utelat grupper fra passordkrav",
    "Exclude groups from creating link shares" : "Ekskluder grupper fra å opprette delte koblingsressurser",
    "Limit sharing based on groups" : "Begrens deling basert på grupper",
    "Allow sharing for everyone (default)" : "Tillat deling for alle (standard)",
    "Exclude some groups from sharing" : "Utelukk noen grupper fra deling",
    "Limit sharing to some groups" : "Begrens deling til noen grupper",
    "Groups allowed to share" : "Grupper som kan dele",
    "Groups excluded from sharing" : "Grupper ekskludert fra deling",
    "Not allowed groups will still be able to receive shares, but not to initiate them." : "Ikke tillatte grupper vil fortsatt kunne motta delinger, men ikke starte dem.",
    "Enforce expiration date" : "Krev utløpsdato",
    "Default expiration time of new shares in days" : "Standard utløpstid for nye delinger i dager",
    "Expire shares after x days" : "Utløp delinger etter x dager",
    "Set default expiration date for shares to other servers" : "Angi standard utløpsdato for delinger til andre servere",
    "Enforce expiration date for remote shares" : "Håndhev utløpsdato for eksterne delinger",
    "Default expiration time of remote shares in days" : "Standard utløpstid for eksterne delinger i dager",
    "Expire remote shares after x days" : "Utløp eksterne delinger etter x dager",
    "Set default expiration date for shares via link or mail" : "Angi standard utløpsdato for delinger via lenke eller e-post",
    "Default expiration time of shares in days" : "Standard utløpstid for delinger i dager",
    "Privacy settings for sharing" : "Personverninnstillinger for deling",
    "Allow account name autocompletion in share dialog and allow access to the system address book" : "Tillat automatisk fullføring av kontonavn i delingsdialogen og gi tilgang til systemets adressebok",
    "Restrict account name autocompletion and system address book access to users within the same groups" : "Begrens automatisk fullføring av kontonavn og tilgang til systemadressebok til brukere i de samme gruppene",
    "Show disclaimer text on the public link upload page (only shown when the file list is hidden)" : "Vis ansvarsfraskrivelse på den offentlige lenkeopplastingssiden (vises bare når fillisten er skjult)",
    "Disclaimer text" : "Ansvarsfraskrivelse tekst",
    "This text will be shown on the public link upload page when the file list is hidden." : "Denne teksten vises på den offentlig opplastingssiden når fillisten er tom.",
    "Default share permissions" : "Standard delingsrettigheter",
    "Two-Factor Authentication" : "Tofaktor-autentisering",
    "Two-factor authentication can be enforced for all accounts and specific groups. If they do not have a two-factor provider configured, they will be unable to log into the system." : "Tofaktorautentisering kan håndheves for alle kontoer og bestemte grupper. Hvis de ikke har en tofaktorleverandør konfigurert, vil de ikke kunne logge seg på systemet.",
    "Enforce two-factor authentication" : "Krev tofaktor-autentisering",
    "Limit to groups" : "Begrens til grupper",
    "Enforcement of two-factor authentication can be set for certain groups only." : "Håndheving av tofaktor-autentisering kan bare settes for enkelte grupper.",
    "Two-factor authentication is enforced for all members of the following groups." : "Tofaktor-autentisering er påkrevd for alle medlemmer i følgende grupper.",
    "Enforced groups" : "Håndhevde grupper",
    "Two-factor authentication is not enforced for members of the following groups." : "Tofaktor-autentisering er ikke påkrevd for medlemmer i følgende grupper.",
    "Excluded groups" : "Utelukkede grupper",
    "When groups are selected/excluded, they use the following logic to determine if an account has 2FA enforced: If no groups are selected, 2FA is enabled for everyone except members of the excluded groups. If groups are selected, 2FA is enabled for all members of these. If an account is both in a selected and excluded group, the selected takes precedence and 2FA is enforced." : "Når grupper velges/ekskluderes, bruker de følgende logikk for å avgjøre om en konto har 2FA håndhevet: Hvis ingen grupper er valgt, aktiveres 2FA for alle unntatt medlemmer av de ekskluderte gruppene. Hvis grupper velges, er 2FA aktivert for alle medlemmer av disse. Hvis en konto er både i en valgt og ekskludert gruppe, har den valgte forrang og 2FA håndheves.",
    "Save changes" : "Lagre endringer",
    "Default" : "Forvalg",
    "Registered Deploy daemons list" : "Registrert liste over distribuerings-daemoner",
    "No Deploy daemons configured" : "Ingen distribuerings-daemoner konfigurert",
    "Register a custom one or setup from available templates" : "Registrer en tilpasset en eller sett opp fra tilgjengelige maler",
    "Show details for {appName} app" : "Vis detaljer for {appName}-app",
    "Update to {update}" : "Oppdater til {update}",
    "Remove" : "Fjern",
    "Featured" : "Anbefalt",
    "This app is supported via your current Nextcloud subscription." : "Denne appen er støttet av ditt nåværende Nextcloud abonnement.",
    "Featured apps are developed by and within the community. They offer central functionality and are ready for production use." : "Anbefalte apper er utviklet av og innenfor fellesskapet. De tilbyr sentral funksjonalitet og er klare for bruk i produksjon.",
    "Community rating: {score}/5" : "Samfunnsvurdering: {score}/5",
    "Disable all" : "Deaktiver alle",
    "Download and enable all" : "Last ned og aktiver alle",
    "All apps are up-to-date." : "Alle apper er oppdatert.",
    "Icon" : "Ikon",
    "Name" : "Navn",
    "Version" : "Versjon",
    "Level" : "Nivå",
    "Actions" : "Handlinger",
    "Results from other categories" : "Resultater fra andre kategorier",
    "No apps found for your version" : "Ingen apper funnet for din versjon",
    "_%n app has an update available_::_%n apps have an update available_" : ["%n app har en oppdatering tilgjengelig","%n apper har en oppdatering tilgjengelig"],
    "_Update_::_Update all_" : ["Oppdater","Oppdater alle"],
    "Failed to create group" : "Kunne ikke opprette gruppe",
    "Creating group…" : "Oppretter gruppe...",
    "Create group" : "Opprett gruppe",
    "Group name" : "Gruppenavn",
    "Please enter a valid group name" : "Vennligst angi et gyldig gruppenavn",
    "Loading groups…" : "Laster grupper...",
    "Could not load app discover section" : "Kunne ikke laste inn appoppdagelsesdelen",
    "Could not render element" : "Kunne ikke gjengi element",
    "Nothing to show" : "Ingenting å vise her",
    "Could not load section content from app store." : "Kunne ikke laste inn seksjonsinnhold fra app store.",
    "Loading" : "Lasting",
    "Fetching the latest news…" : "Henter siste nyheter...",
    "Carousel" : "Karusell",
    "Previous slide" : "Forrige lysbilde",
    "Next slide" : "Neste lysbilde",
    "Choose slide to display" : "Velg lysbilde som skal vises",
    "{index} of {total}" : "{index} av {total}",
    "Daemon" : "Nisse",
    "Deploy Daemon" : "Distribuerings-daemon",
    "Type" : "Type",
    "Display Name" : "Visningsnavn",
    "GPUs support" : "Støtte for GPUer",
    "Compute device" : "Beregningsenhet",
    "Learn more" : "Lær mer",
    "Confirm" : "Bekreft",
    "Cancel" : "Avbryt",
    "Description" : "Beskrivelse",
    "View in store" : "Vis i butikk",
    "Visit website" : "Besøk nettsiden",
    "Usage documentation" : "Bruksdokumentasjon",
    "Admin documentation" : "Administratordokumentasjon",
    "Developer documentation" : "Utviklerdokumentasjon",
    "Details" : "Detaljer",
    "All" : "Alle",
    "Limit app usage to groups" : "Begrens app-bruk til grupper",
    "No results" : "Ingen resultater",
    "Update to {version}" : "Oppdater til {version}",
    "Default Deploy daemon is not accessible" : "Standard distribuerings-daemon er ikke tilgjengelig.",
    "Delete data on remove" : "Slett data ved fjerning",
    "This app cannot be installed because the following dependencies are not fulfilled:" : "Denne appen kan ikke installeres fordi følgende avhengigheter ikke er tilfredsstilt:",
    "Latest updated" : "Sist oppdatert",
    "Author" : "Forfatter",
    "Categories" : "Kategorier",
    "Resources" : "Ressurser",
    "Documentation" : "Dokumentasjon",
    "Interact" : "Samhandle",
    "Report a bug" : "Rapporter en feil",
    "Request feature" : "Ønsk en funksjon",
    "Ask questions or discuss" : "Still spørsmål og diskuter",
    "Rate the app" : "Vurder appen",
    "Rate" : "Vurder",
    "Changelog" : "Endringslogg",
    "Google Chrome for Android" : "Google Chrome for Android",
    "{productName} iOS app" : "{productName} iOS-app",
    "{productName} Android app" : "{productName} Android-app",
    "{productName} Talk for iOS" : "{productName} Talk for iOS",
    "{productName} Talk for Android" : "{productName} Talk for Android",
    "Sync client" : "Synkroniser klient",
    "This session" : "Denne økten",
    "{client} - {version} ({system})" : "{client} - {version} ({system})",
    "{client} - {version}" : "{client} - {version}",
    "Device name" : "Enhetsnavn",
    "Cancel renaming" : "Avbryt gi nytt navn",
    "Save new name" : "Lagre nytt navn",
    "Marked for remote wipe" : "Markert for fjernsletting",
    "Device settings" : "Enhetsinnstillinger",
    "Allow filesystem access" : "Tillatt filsystemtilgang",
    "Rename" : "Endre navn",
    "Revoke" : "Avslå",
    "Wipe device" : "Slett enhet",
    "Revoking this token might prevent the wiping of your device if it has not started the wipe yet." : "Hvis du opphever dette tokenet, kan det forhindre sletting av enheten hvis det ikke har startet slettingen enda.",
    "Device" : "Enhet",
    "Last activity" : "Seneste aktivitet",
    "Devices & sessions" : "Enheter og økter",
    "Web, desktop and mobile clients currently logged in to your account." : "Følgende nett, skrivebord og mobile klienter er for øyeblikket logget på din konto.",
    "Error while creating device token" : "Feil under opprettelse av enhetsnøkkel",
    "App name" : "App-navn",
    "Create new app password" : "Lag nytt apppassord",
    "App password copied!" : "App-passord kopiert!",
    "Copy app password" : "Kopier app-passord",
    "Login name copied!" : "Påloggingsnavnet er kopiert!",
    "Copy login name" : "Kopier påloggingsnavn",
    "Could not copy app password. Please copy it manually." : "Kunne ikke kopiere passord. Venligst kopier manuelt.",
    "Could not copy login name. Please copy it manually." : "Kunne ikke kopiere påloggingsnavnet. Vennligst kopier det manuelt.",
    "New app password" : "Nytt app-passord",
    "Use the credentials below to configure your app or device. For security reasons this password will only be shown once." : "Bruk legitimasjonen nedenfor til å konfigurere appen eller enheten. Av sikkerhetsmessige årsaker vises dette passordet bare én gang.",
    "Login" : "Innlogging",
    "Password" : "Passord",
    "Show QR code for mobile apps" : "Vis QR-kode for mobilapper",
    "Use system cron service to call the cron.php file every 5 minutes." : "Bruk system cron-service for å kalle cron.php filen hvert 5. minutt.",
    "The cron.php needs to be executed by the system account \"{user}\"." : "Cron.php må kjøres av systemkontoen \"{user}\".",
    "The PHP POSIX extension is required. See {linkstart}PHP documentation{linkend} for more details." : "PHP POSIX-utvidelsen er nødvendig. Se {linkstart}PHP-dokumentasjon{linkend} for flere detaljer.",
    "Unable to update background job mode" : "Kan ikke oppdatere bakgrunnsjobbmodus",
    "For the server to work properly, it's important to configure background jobs correctly. Cron is the recommended setting. Please see the documentation for more information." : "For at serveren skal fungere ordentlig, er det viktig å konfigurere bakgrunnsjobber riktig. Cron er den anbefalte innstillingen. Vennligst se dokumentasjonen for mer informasjon.",
    "Last job execution ran {time}. Something seems wrong." : "Siste jobb kjørte {time}. Noe virker galt.",
    "Last job ran {relativeTime}." : "Siste jobb kjørte {relativeTime}.",
    "Background job did not run yet!" : "Bakgrunnsjobben er ikke kjørt ennå!",
    "AJAX" : "AJAX",
    "Execute one task with each page loaded. Use case: Single account instance." : "Utfør én oppgave med hver side lastet inn. Brukstilfelle: enkelkontoforekomst.",
    "Webcron" : "Webcron",
    "cron.php is registered at a webcron service to call cron.php every 5 minutes over HTTP. Use case: Very small instance (1–5 accounts depending on the usage)." : "cron.php er registrert på en webcron-tjeneste for å ringe cron.php hvert 5. minutt over HTTP. Brukstilfelle: Svært liten forekomst (1–5 brukere avhengig av bruken).",
    "Cron (Recommended)" : "Cron (anbefalt)",
    "Unable to update profile default setting" : "Kan ikke oppdatere profilens standardinnstilling",
    "Profile" : "Profil",
    "Enable or disable profile by default for new accounts." : "Aktiver eller deaktiver profil som standard for nye kontoer.",
    "Password confirmation is required" : "Passord bekreftelse er nødvendig",
    "Failed to save setting" : "Lagring av innstilling feilet",
    "{app}'s declarative setting field: {name}" : "{app}s deklarative innstillingsfelt: {name}",
    "Unable to update server side encryption config" : "Kan ikke oppdatere konfigurasjonen av server-side-kryptering",
    "Server-side encryption" : "Server-side-kryptering",
    "Server-side encryption makes it possible to encrypt files which are uploaded to this server. This comes with limitations like a performance penalty, so enable this only if needed." : "Server-side-kryptering gjør det mulig å kryptere files som er lastet opp til denne serveren. Dette har begrensninger som ytelsesforverring, så bare skru på dette hvis det trengs.",
    "Enable server-side encryption" : "Aktiver server-side-kryptering",
    "No encryption module loaded, please enable an encryption module in the app menu." : "Ingen krypteringsmodul er lastet. Aktiver en krypteringsmodul i appmenyen.",
    "Select default encryption module:" : "Velg forvalgt krypteringsmodul:",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run {command}" : "Du må migrere krypteringsnøklene dine fra den gamle krypteringen (ownCloud <= 8.0) til den nye. Aktiver \"Standard krypteringsmodul\" og kjør {command}.",
    "Enable encryption" : "Aktiver kryptering",
    "Please read carefully before activating server-side encryption:" : "Les nøye før du aktiverer server-side-kryptering:",
    "Once encryption is enabled, all files uploaded to the server from that point forward will be encrypted at rest on the server. It will only be possible to disable encryption at a later date if the active encryption module supports that function, and all pre-conditions (e.g. setting a recover key) are met." : "Når kryptering er blitt aktivert, vil alle filer som lastes opp til serveren fra det tidspunktet av bli lagret kryptert på serveren. Det vil kun være mulig å deaktivere kryptering senere dersom den aktive krypteringsmodulen støtter det og alle forutsetninger (f.eks. å sette en gjenopprettingsnøkkel) er til stede.",
    "Encryption alone does not guarantee security of the system. Please see documentation for more information about how the encryption app works, and the supported use cases." : "Krypteringen alene gir ikke noen garanti for systemets sikkerhet. Sjekk Nextcloud-dokumentasjonen for mer informasjon om hvordan krypteringsappen virker, og de fungerende brukseksemplene.",
    "Be aware that encryption always increases the file size." : "Vær oppmerksom på at kryptering alltid øker filstørrelsen.",
    "It is always good to create regular backups of your data, in case of encryption make sure to backup the encryption keys along with your data." : "Det er alltid bra å ta regelmessig sikkerhetskopi av dataene dine. Pass på å ta kopi av krypteringsnøklene sammen med dataene når kryptering er i bruk.",
    "This is the final warning: Do you really want to enable encryption?" : "Dette er siste advarsel: Vil du virkelig aktivere kryptering?",
    "Please confirm the group removal" : "Vennligst bekreft fjerning av gruppe",
    "Submit" : "Send inn",
    "Rename group" : "Gi nytt navn til gruppen",
    "Current password" : "Nåværende passord",
    "New password" : "Nytt passord",
    "Change password" : "Endre passord",
    "Choose your profile picture" : "Velg profilbildet ditt",
    "Please select a valid png or jpg file" : "Velg en gyldig png- eller jpg-fil",
    "Error setting profile picture" : "Feil ved setting av profilbilde",
    "Error cropping profile picture" : "Feil under beskjæring av profilbilde",
    "Error saving profile picture" : "Feil under lagring av profilbilde",
    "Error removing profile picture" : "Feil ved fjerning av profilbilde",
    "Your profile picture" : "Ditt profilbilde",
    "Upload profile picture" : "Last opp profilbilde",
    "Choose profile picture from Files" : "Velg profilbilde fra Files",
    "Remove profile picture" : "Fjern profilbilde",
    "The file must be a PNG or JPG" : "Filen må være en .PNG eller .JPG",
    "Picture provided by original account" : "Bilde kommer fra opprinnelig konto",
    "Set as profile picture" : "Angi som profilbilde",
    "Please note that it can take up to 24 hours for your profile picture to be updated everywhere." : "Vær oppmerksom på at det kan ta opptil 24 timer før profilbildet ditt blir oppdatert overalt.",
    "Unable to update date of birth" : "Kan ikke oppdatere fødselsdato",
    "Enter your date of birth" : "Skriv inn fødselsdatoen din",
    "You are using {s}{usage}{/s}" : "Du bruker {s}{usage}{/s}",
    "You are using {s}{usage}{/s} of {s}{totalSpace}{/s} ({s}{usageRelative}%{/s})" : "Du bruker {s}{usage}{/s} of {s}{totalSpace}{/s} ({s}{usageRelative}%{/s})",
    "You are a member of the following groups:" : "Du er medlem av følgende grupper:",
    "Your full name" : "Ditt fulle navn",
    "Email options" : "Alternativer for e-post",
    "Options for additional email address {index}" : "Alternativer for ekstra e-postadresse {index}",
    "Remove primary email" : "Fjern primær e-post",
    "Delete email" : "Slett e-post",
    "This address is not confirmed" : "Denne adressen er ikke bekreftet",
    "Unset as primary email" : "Deaktivert som primær e-post",
    "Set as primary email" : "Angi som primær e-post",
    "Additional email address {index}" : "Ekstra e-postadresse {index}",
    "Unable to delete primary email address" : "Kan ikke slette primær e-postadresse",
    "Unable to update primary email address" : "Kan ikke oppdatere primær e-postadresse",
    "Unable to add additional email address" : "Kan ikke legge til ytterligere e-postadresse",
    "Unable to update additional email address" : "Kan ikke oppdatere ytterligere e-postadresse",
    "Unable to delete additional email address" : "Kan ikke slette ytterligere e-postadresse",
    "Primary email for password reset and notifications" : "Primær e-postadresse for tilbakestilling av passord og varsler",
    "No email address set" : "E-postadresse ikke satt",
    "Your handle" : "Ditt brukernavn",
    "Derived from your locale ({weekDayName})" : "Avledet fra din nasjonale innstilling ({weekDayName})",
    "Unable to update first day of week" : "Kan ikke oppdatere første dag i uken",
    "Day to use as the first day of week" : "Dag som skal brukes som første dag i uken",
    "Your headline" : "Din overskrift",
    "Unable to update language" : "Kan ikke oppdatere språket",
    "Languages" : "Språk",
    "Help translate" : "Bidra til oversettelsen",
    "No language set" : "Språk ikke satt",
    "Unable to update locale" : "Kan ikke oppdatere lokaliteten",
    "Locales" : "Nasjonale innstillinger",
    "Week starts on {firstDayOfWeek}" : "Uken starter på {firstDayOfWeek}",
    "No locale set" : "Ingen nasjonal innstilling angitt",
    "Your city" : "Byen din",
    "Your organisation" : "Din organisasjon",
    "Your phone number" : "Ditt telefonnummer",
    "Edit your Profile visibility" : "Endre synlighet for din profil",
    "Unable to update profile enabled state" : "Kan ikke oppdatere profilaktivert tilstand",
    "Enable profile" : "Aktiver profil",
    "The more restrictive setting of either visibility or scope is respected on your Profile. For example, if visibility is set to \"Show to everyone\" and scope is set to \"Private\", \"Private\" is respected." : "Den mest restriktive innstillingen synlighet eller omfang respekteres på profilen din. For eksempel, hvis synlighet er satt til \"Vis til alle\" og omfanget er satt til \"Privat\", respekteres \"Privat\".",
    "Unable to update visibility of {displayId}" : "Kan ikke oppdatere synligheten til {displayId}",
    "she/her" : "hun/henne",
    "he/him" : "han/ham",
    "they/them" : "de/dem",
    "Your role" : "Din rolle",
    "Timezone" : "Tidssone",
    "Your X (formerly Twitter) handle" : "Ditt X- (tidligere Twitter) brukernavn",
    "Your website" : "Din nettside",
    "Invalid value" : "Ugyldig verdi",
    "Unable to update {property}" : "Kan ikke oppdatere {property}",
    "No {property} set" : "Ingen {property} satt",
    "Change scope level of {property}, current scope is {scope}" : "Endre omfangsnivå til {property}, gjeldende omfang er {scope}",
    "Unable to update federation scope of the primary {property}" : "Kan ikke oppdatere føderasjonsomfanget for den primære {property}",
    "Unable to update federation scope of additional {property}" : "Kan ikke oppdatere føderasjonsomfanget for ytterligere {property}",
    "Add additional email" : "Legg til ekstra e-post",
    "Add" : "Legg til",
    "Create" : "Opprett",
    "Change" : "Endre",
    "Delete" : "Slett",
    "Reshare" : "Videredele",
    "School" : "Skole",
    "Default language" : "Standard språk",
    "Common languages" : "Vanlige språk",
    "Other languages" : "Andre språk",
    "Password change is disabled because the master key is disabled" : "Passordendring er deaktivert fordi hoved-nøkkelen er deaktivert",
    "No accounts" : "Ingen kontoer",
    "Loading accounts …" : "Laster kontoer…",
    "List of accounts. This list is not fully rendered for performance reasons. The accounts will be rendered as you navigate through the list." : "Liste over kontoer. Denne listen er ikke fullstendig gjengitt av ytelsesgrunner. Kontoene blir gjengitt når du navigerer gjennom listen.",
    "Manager" : "Sjef",
    "Set line manager" : "Angi linjeleder",
    "Account name will be autogenerated" : "Kontonavnet blir automatisk generert",
    "Account name (required)" : "Kontonavn (obligatorisk)",
    "New account" : "Ny konto",
    "Display name" : "Visningsnavn",
    "Either password or email is required" : "Enten passord eller e-post kreves",
    "Password (required)" : "Passord (kreves)",
    "Email (required)" : "E-post (kreves)",
    "Email" : "E-post",
    "Member of the following groups (required)" : "Medlem av følgende grupper (obligatorisk)",
    "Member of the following groups" : "Medlem av følgende grupper",
    "Set account groups" : "Angi kontogrupper",
    "Admin of the following groups" : "Administrator for følgende grupper",
    "Set account as admin for …" : "Angi konto som administrator for...",
    "Quota" : "Kvote",
    "Set account quota" : "Angi kontokvote",
    "Language" : "Språk",
    "Set default language" : "Angi standard språk",
    "Add new account" : "Legg til ny konto",
    "_{userCount} account …_::_{userCount} accounts …_" : ["{userCount} konto…","{userCount} kontoer…"],
    "_{userCount} account_::_{userCount} accounts_" : ["{userCount} konto","{userCount} kontoer"],
    "Total rows summary" : "Sammendrag av totalrader",
    "Scroll to load more rows" : "Rull for å laste inn flere rader",
    "Password or insufficient permissions message" : "Melding om passord eller utilstrekkelige rettigheter",
    "Avatar" : "Avatar",
    "Account name" : "Kontonavn",
    "Group admin for" : "Gruppeadministrator for",
    "Account backend" : "Konto-backend",
    "Storage location" : "Lagringsplassering",
    "First login" : "Første innlogging",
    "Last login" : "Siste innlogging",
    "Account actions" : "Kontoaktiviteter",
    "{size} used" : "{size} brukt",
    "Delete account" : "Slett konto",
    "Disconnect all devices and delete local data" : "Frakoble alle enheter og slett lokal data",
    "Disable account" : "Deaktiver konto",
    "Enable account" : "Aktiver konto",
    "Resend welcome email" : "Send velkomst-epost igjen",
    "Remote wipe of devices" : "Fjernsletting av enheter",
    "Wipe {userid}'s devices" : "Tøm enhetene til {userid}",
    "Wiped {userid}'s devices" : "Slettet {userid}s enheter",
    "Failed to update line manager" : "Oppdatering av linjeleder feilet",
    "Fully delete {userid}'s account including all their personal files, app data, etc." : "Slett {userid} sin konto fullstendig, inkludert alle personlige filer, appdata osv.",
    "Account deletion" : "Sletting av konto",
    "Delete {userid}'s account" : "Slett {userid} sin konto",
    "Display name was successfully changed" : "Visningsnavn ble endret",
    "Password was successfully changed" : "Passord ble endret",
    "Email was successfully changed" : "E-post ble endret",
    "Welcome mail sent!" : "Velkomst-epost sendt!",
    "Loading account …" : "Laster konto…",
    "Change display name" : "Endre visningsnavn",
    "Set new password" : "Angi nytt passord",
    "You do not have permissions to see the details of this account" : "Du har ikke tillatelser til å se detaljer om denne kontoen",
    "Set new email address" : "Angi ny e-postadresse",
    "Add account to group" : "Legg konto til gruppe",
    "Set account as admin for" : "Angi konto som administrator for",
    "Select account quota" : "Velg kontokvote",
    "Set the language" : "Angi språk",
    "Toggle account actions menu" : "Veksle meny over kontohandlinger",
    "Done" : "Ferdig",
    "Edit" : "Rediger",
    "Account management settings" : "Innstillinger for kontoadministrasjon",
    "Visibility" : "Synlighet",
    "Show language" : "Vis språk",
    "Show account backend" : "Vis konto-server",
    "Show storage path" : "Vis lagringsplassering",
    "Show first login" : "Vis første innlogging",
    "Show last login" : "Vis siste innlogging",
    "Sorting" : "Sorter",
    "The system config enforces sorting the groups by name. This also disables showing the member count." : "Systemkonfigurasjonen håndhever sortering av gruppene etter navn. Dette deaktiverer også visning av medlemsantallet.",
    "Group list sorting" : "Gruppeliste sortering",
    "By member count" : "Etter medlemsantall",
    "By name" : "Etter navn",
    "Send email" : "Send e-post",
    "Send welcome email to new accounts" : "Sende velkomst-e-post til nye kontoer",
    "Defaults" : "Standarder",
    "Default quota" : "Standard kvote",
    "Select default quota" : "Sett standard kvote",
    "Server error while trying to complete WebAuthn device registration" : "Serverfeil under forsøk på å fullføre WebAuthn-enhetsregistrering",
    "Passwordless authentication requires a secure connection." : "Passordløs autentisering krever en sikker tilkobling.",
    "Add WebAuthn device" : "Legg til WebAuthn-enhet",
    "Please authorize your WebAuthn device." : "Vennligst autoriser WebAuthn-enheten din",
    "Adding your device …" : "Legger til enheten...",
    "Unnamed device" : "Ikke navngitt enhet",
    "Passwordless Authentication" : "Passordløs autentisering",
    "Set up your account for passwordless authentication following the FIDO2 standard." : "Sett opp kontoen din for passordløs autentisering i henhold til FIDO2-standarden.",
    "No devices configured." : "Ingen enheter konfigurert.",
    "The following devices are configured for your account:" : "Følgende enheter er konfigurert for kontoen din:",
    "Your browser does not support WebAuthn." : "Nettleseren din støtter ikke WebAuthn.",
    "Security & setup warnings" : "Advarsler om sikkerhet og oppsett",
    "Try again" : "Prøv igjen",
    "All checks passed." : "Alle sjekker bestått.",
    "There are some errors regarding your setup." : "Det er noen feil angående oppsettet ditt.",
    "There are some warnings regarding your setup." : "Det er noen advarsler angående oppsettet ditt.",
    "As admin you can fine-tune the sharing behavior. Please see the documentation for more information." : "Som administrator kan du fininnstille delingsoppførselen. Se dokumentasjonen for mer informasjon.",
    "You need to enable the File sharing App." : "Du trenger å aktivere fildelingsappen.",
    "App Store" : "Appbutikk",
    "Loading app list" : "Laster appliste",
    "Loading categories" : "Laster kategorier",
    "Developer documentation ↗" : "Utviklerdokumentasjon ↗",
    "Version {version}, {license}-licensed" : "Versjon {version}, {license}-lisensiert",
    "Version {version}" : "Versjon {version}",
    "Apply" : "Bruk",
    "All accounts" : "Alle kontoer",
    "Admins" : "Administratorer",
    "Account group: {group}" : "Kontogruppe: {group}",
    "Account management" : "Kontoadministrasjon",
    "Sending…" : "Sender…",
    "Email sent" : "E-post sendt",
    "Location" : "Sted",
    "Profile picture" : "Profilbilde",
    "About" : "Om",
    "Date of birth" : "Fødselsdato",
    "Full name" : "Fullt navn",
    "Additional email" : "Ytterligere e-post",
    "Fediverse (e.g. Mastodon)" : "Fediverse (f.eks. Mastodon)",
    "Headline" : "Overskrift",
    "Organisation" : "Organisasjon",
    "Phone number" : "Telefonnummer",
    "Pronouns" : "Pronomen",
    "Role" : "Rolle",
    "X (formerly Twitter)" : "X (tidligere Twitter)",
    "Website" : "Nettsted",
    "Profile visibility" : "Profil-synlighet",
    "Locale" : "Nasjonal innstilling",
    "First day of week" : "Første dag i uken",
    "Not available as this property is required for core functionality including file sharing and calendar invitations" : "Ikke tilgjengelig siden denne egenskapen kreves for kjernefunksjonalitet, inkludert fildeling og kalenderinvitasjoner.",
    "Not available as federation has been disabled for your account, contact your system administration if you have any questions" : "Ikke tilgjengelig ettersom sammenknytning er deaktivert for kontoen din. Kontakt systemadministratoren hvis du har spørsmål.",
    "Not available as publishing account specific data to the lookup server is not allowed, contact your system administration if you have any questions" : "Ikke tilgjengelig da publisering av kontospesifikke data til oppslagsserveren ikke er tillatt, kontakt systemadministratoren hvis du har spørsmål.",
    "Discover" : "Oppdag",
    "Your apps" : "Dine apper",
    "Active apps" : "Aktive apper",
    "Disabled apps" : "Deaktiverte apper",
    "Updates" : "Oppdateringer",
    "App bundles" : "App-pakker",
    "Featured apps" : "Fremhevede apper",
    "Supported apps" : "Støttede apper",
    "Show to everyone" : "Vis til alle",
    "Show to logged in accounts only" : "Vis kun for påloggede kontoer",
    "Hide" : "Skjul",
    "Deploy and Enable" : "Distribuer og aktiver",
    "Download and enable" : "Last ned og aktiver",
    "Disable" : "Deaktiver ",
    "Allow untested app" : "Tillatt utestet app",
    "The app will be downloaded from the App Store" : "Appen vil bli lastet ned fra app-butikken",
    "Unknown" : "Ukjent",
    "Never" : "Aldri",
    "Could not register device: Network error" : "Kunne ikke registrere enheten: nettverksfeil",
    "Could not register device: Probably already registered" : "Kunne ikke registrere enheten: trolig allerede registrert",
    "Could not register device" : "Kunne ikke registrere enheten",
    "An error occurred during the request. Unable to proceed." : "En feil oppstod under forespørselen. Kan ikke fortsette.",
    "The app has been enabled but needs to be updated." : "Appen er aktivert, men må oppdateres.",
    "Error: This app cannot be enabled because it makes the server unstable" : "Feil: denne appen kan ikke aktiveres fordi det gjør serveren ustabil",
    "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "Appen er aktivert men må oppdateres. Du vil bli videresendt til oppdateringssiden om 5 sekunder.",
    "Do you really want to wipe your data from this device?" : "Vil du virkelig slette dine data fra denne enheten?",
    "Confirm wipe" : "Bekreft sletting",
    "Could not delete the app token" : "Kunne ikke slette apptokenet",
    "Error while wiping the device with the token" : "Feil under sletting av enheten med tokenet",
    "Error while updating device token name" : "Feil under oppdatering av navn på enhetstoken",
    "Error while updating device token scope" : "Feil under oppdatering av omfang av enhetstoken",
    "Could not set group sorting" : "Kunne ikke angi gruppesortering",
    "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "Det var for mange forespørsler fra ditt nettverk. Prøv igjen senere eller kontakt din administrator hvis dette er en feil.",
    "Error" : "Feil",
    "Account documentation" : "Kontodokumentasjon",
    "Administration documentation" : "Dokumentasjon for administrasjon",
    "Forum" : "Forum",
    "Nextcloud help & privacy resources" : "Nextcloud hjelp og personvernressurser",
    "General documentation" : "Generell dokumentasjon",
    "Legal notice" : "Juridisk varsel",
    "Privacy policy" : "Personvern politikk",
    "None/STARTTLS" : "None/STARTTLS",
    "SSL" : "SSL",
    "Open documentation" : "Åpne dokumentasjonen",
    "It is important to set up this server to be able to send emails, like for password reset and notifications." : "Det er viktig å sette opp denne serveren for å kunne sende e-poster, som tilbakestilling av e-poster og merknader.",
    "Send mode" : "Forsendelsesmåte",
    "Encryption" : "Kryptering",
    "Sendmail mode" : "Sendmail-modus",
    "From address" : "Fra adresse",
    "Server address" : "Serveradresse",
    "Port" : "Port",
    "Authentication" : "Autentisering",
    "Authentication required" : "Autentisering kreves",
    "Credentials" : "Påloggingsdetaljer",
    "SMTP Login" : "SMTP-pålogging",
    "SMTP Password" : "SMTP-passord",
    "Save" : "Lagre",
    "Test and verify email settings" : "Test og bekreft e-postinnstillinger",
    "Reasons to use Nextcloud in your organization" : "Grunner til å bruke Nextcloud i organisasjonen din",
    "Developed by the {communityopen}Nextcloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}AGPL{linkclose}." : "Utviklet av {communityopen}Nextcloud-miljøet{linkclose},  {githubopen}kildekoden{linkclose} er lisensiert under {licenseopen}AGPL{linkclose}.",
    "Like our Facebook page" : "Lik vår Facebook-side",
    "Follow us on X" : "Følg oss på X",
    "Follow us on Mastodon" : "Følg oss på Mastadon",
    "Check out our blog" : "Sjekk ut bloggen vår",
    "Subscribe to our newsletter" : "Abonner på vårt nyhetsbrev",
    "This community release of Nextcloud is unsupported and instant notifications are unavailable." : "Denne community-utgaven av NextCloud er ikke understøttet og umiddelbare varsler er derfor ikke tilgjengelig. ",
    "Use a second factor besides your password to increase security for your account." : "Bruk en annen faktor i tillegg til passordet ditt for å øke sikkerheten for kontoen din.",
    "If you use third party applications to connect to Nextcloud, please make sure to create and configure an app password for each before enabling second factor authentication." : "Hvis du bruker tredjepartsapplikasjoner for å koble til Nextcloud, må du sørge for å opprette og konfigurere et app-passord for hver før du aktiverer tofaktorautentisering.",
    "Logged in account must be a subadmin" : "Pålogget konto må være en underadministrator",
    "To allow this check to run you have to make sure that your Web server can connect to itself. Therefore it must be able to resolve and connect to at least one of its `trusted_domains` or the `overwrite.cli.url`. This failure may be the result of a server-side DNS mismatch or outbound firewall rule." : "For å la denne kontrollen kjøre, må du sørge for at webserveren din kan koble til seg selv. Derfor må den kunne løse og koble til minst en dens 'trusted_domains' eller 'overwrite.cli.url'. Denne feilen kan være et resultat av ikke-DNS-samsvar på serversiden eller en regel for utgående brannmur.",
    "File locking" : "Låsing av filer",
    "Transactional file locking is disabled, this might lead to issues with race conditions. Enable \"filelocking.enabled\" in config.php to avoid these problems." : "Låsing av transaksjonsfiler er deaktivert, dette kan føre til problemer med løpsforholdene. Aktiver \"filelocking.enabled\" i config.php for å unngå disse problemene.",
    "The PHP memory limit is below the recommended value of %s." : "PHP-minnegrensen er under den anbefalte verdien på %s.",
    "for WebAuthn passwordless login" : "for WebAuthn-passordfripålogging",
    "for WebAuthn passwordless login, and SFTP storage" : "for WebAuthn-passordfripålogging og SFTP-lagring",
    "- The `%1$s` HTTP header does not contain `%2$s`. This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "- HTTP-hodet '%1$s' inneholder ikke '%2$s'. Dette er en potensiell sikkerhets- eller personvernrisiko, da det anbefales å justere denne innstillingen tilsvarende.",
    "PostgreSQL version \"%s\" detected. PostgreSQL >=12 and <=16 is suggested for best performance, stability and functionality with this version of Nextcloud." : "PostgreSQL-versjon \"%s\" oppdaget. PostgreSQL >=12 og <=16 foreslås for best ytelse, stabilitet og funksjonalitet med denne versjonen av Nextcloud.",
    "Set default expiration date for shares" : "Angi standard utløpsdato for delinger",
    "If autocompletion \"same group\" and \"phone number integration\" are enabled a match in either is enough to show the user." : "Hvis autofullføring \"samme gruppe\" og \"telefonnummerintegrasjon\" er aktivert, er en match i begge nok til å vise brukeren.",
    "Restrict account name autocompletion to users based on phone number integration" : "Begrens automatisk fullføring av kontonavn til brukere basert på integrering av telefonnummer",
    "Allow autocompletion when entering the full name or email address (ignoring missing phonebook match and being in the same group)" : "Tillat autofullføring når du skriver inn fullt navn eller e-postadresse (ignorerer manglende telefonbok-treff og er i samme gruppe)",
    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "Denne appen har ingen minimumversjon av Nextcloud definert. Dette vil være en feil i fremtiden.",
    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "Denne appen har ingen høyeste versjon av Nextcloud definert. Dette vil være en feil i fremtiden.",
    "Your biography" : "Din biografi",
    "You are using <strong>{usage}</strong>" : "Du bruker <strong>{usage}</strong>",
    "You are using <strong>{usage}</strong> of <strong>{totalSpace}</strong> (<strong>{usageRelative}%</strong>)" : "Du bruker <strong>{usage}</strong> av <strong>{totalSpace}</strong> (<strong>{usageRelative}%</strong>)",
    "In case of lost device or exiting the organization, this can remotely wipe the Nextcloud data from all devices associated with {userid}. Only works if the devices are connected to the internet." : "I tilfelle man har mistet enheter eller skal ut av organisasjonen, så kan dette fjernslette Nextcloud data fra alle enheter tilknyttet bruker med {userid}. Dette fungerer kun dersom enhetene er tilkoblet internett.",
    "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "Denne appen er ikke merket som kompatibel med Nextcloud-versjonen. Hvis du fortsetter, vil du fortsatt kunne installere appen. Vær oppmerksom på at appen kanskje ikke fungerer som forventet.",
    "It's important for the security and performance of your instance that everything is configured correctly. To help you with that we are doing some automatic checks. Please see the linked documentation for more information." : "Det er viktig for sikkerheten og ytelsen på din installasjon at alt er satt opp rett. For å hjelpe deg er det satt i verk noen automatiske sjekker. Se vedlagt lenke for å lese mer i dokumentasjonen.",
    "Checking for system and security issues." : "Sjekker for system- og sikkerhetsfeil.",
    "Please double check the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"%2$s\">log</a>." : "Dobbeltsjekk <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">installasjonsguidene ↗</a> og se etter feil eller advarsler i <a href=\"%2$s\">loggen</a>.",
    "Check the security of your Nextcloud over <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">our security scan ↗</a>." : "Sjekk sikkerheten til din Nextcloud med <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">vår sikkerhetsskanning ↗</a>."
},
"nplurals=2; plural=(n != 1);");
